@@ -54,7 +54,7 @@ for (in_, label) in arrays:
             t0 = time.time()
             blosc.decompress_ptr(c, out.__array_interface__['data'][0])
             td = time.time() - t0
-            assert((in_ == out).all())
+            assert (in_ == out).all()
             print("  *** %-8s, %-10s *** %6.3f s (%.2f GB/s) / %5.3f s (%.2f GB/s)" % (
                 cname, blosc.filters[shuffle], tc, ((N*8 / tc) / 2**30), td, ((N*8 / td) / 2**30)), end='')
             print("\tCompr. ratio: %5.1fx" % (N*8. / len(c)))
